==> ugene_1.25.0%2Bdfsg.orig.tar.xz: ugene-1.25.0/src/plugins_3rdparty/kalign/src/KalignPlugin.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2016 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_KALIGN_PLUGIN_H_
#define _U2_KALIGN_PLUGIN_H_

#include <U2Core/PluginModel.h>
#include <U2Core/AppContext.h>
#include <U2Gui/ObjectViewModel.h>
#include <U2Algorithm/AlignmentAlgorithmsRegistry.h>

#if (QT_VERSION < 0x050000) //Qt 5
#include <QtGui/QMenu>
#else
#include <QtWidgets/QMenu>
#endif

//#include <kalign_local_task/KalignLocalTask.h> //TODO

namespace U2 {

class MSAEditor;
class KalignMSAEditorContext;
class XMLTestFactory;

class KalignPlugin : public Plugin {
    Q_OBJECT
public:
    KalignPlugin();
    ~KalignPlugin();
public slots:
    void sl_runWithExtFileSpecify();

private:
    KalignMSAEditorContext* ctx;
};


class KalignMSAEditorContext: public GObjectViewWindowContext {
    Q_OBJECT
public:
    KalignMSAEditorContext(QObject* p);

protected slots:
    void sl_align();

protected:
    virtual void initViewContext(GObjectView* view);
    virtual void buildMenu(GObjectView* v, QMenu* m);
};

class KalignAction : public GObjectViewAction {
    Q_OBJECT
public:
    KalignAction(QObject* p, GObjectView* v, const QString& text, int order)
        : GObjectViewAction(p,v,text,order) {}
    MSAEditor*  getMSAEditor() const;

private slots:
    void sl_updateState();
};

class KalignPairwiseAligmnentAlgorithm : public AlignmentAlgorithm {
public:
    KalignPairwiseAligmnentAlgorithm();
    bool checkAlphabet(const DNAAlphabet *alphabet) const;
};

} //namespace

#endif

==> ugene_40.1%2Bdfsg.orig.tar.xz: ugene-40.1/src/plugins_3rdparty/kalign/src/KalignPlugin.h <==
/**
 * UGENE - Integrated Bioinformatics Tools.
 * Copyright (C) 2008-2021 UniPro <ugene@unipro.ru>
 * http://ugene.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */

#ifndef _U2_KALIGN_PLUGIN_H_
#define _U2_KALIGN_PLUGIN_H_

#include <QMenu>

#include <U2Algorithm/AlignmentAlgorithmsRegistry.h>

#include <U2Core/AppContext.h>
#include <U2Core/PluginModel.h>

#include <U2Gui/ObjectViewModel.h>

//#include <kalign_local_task/KalignLocalTask.h> //TODO

namespace U2 {

class MSAEditor;
class KalignMSAEditorContext;
class XMLTestFactory;

class KalignPlugin : public Plugin {
    Q_OBJECT
public:
    KalignPlugin();
    ~KalignPlugin();
public slots:
    void sl_runWithExtFileSpecify();

private:
    KalignMSAEditorContext *ctx;
};

class KalignMSAEditorContext : public GObjectViewWindowContext {
    Q_OBJECT
public:
    KalignMSAEditorContext(QObject *p);

protected slots:
    void sl_align();

protected:
    void initViewContext(GObjectView *view) override;
    void buildStaticOrContextMenu(GObjectView *view, QMenu *menu) override;
};

class KalignAction : public GObjectViewAction {
    Q_OBJECT
public:
    KalignAction(QObject *p, GObjectView *v, const QString &text, int order)
        : GObjectViewAction(p, v, text, order) {
    }
    MSAEditor *getMSAEditor() const;

private slots:
    void sl_updateState();
};

class KalignPairwiseAligmnentAlgorithm : public AlignmentAlgorithm {
public:
    KalignPairwiseAligmnentAlgorithm();
    bool checkAlphabet(const DNAAlphabet *alphabet) const;
};

}  // namespace U2

#endif
